@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-
-package B::Hooks::OP::PPAddr;
+package B::Hooks::OP::PPAddr; # git description: 0.04_01-4-gecc7b66
+# ABSTRACT: Hook into opcode execution
 
 use parent qw/DynaLoader/;
 
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 
 sub dl_load_flags { 0x01 }
 
@@ -15,10 +15,18 @@ __PACKAGE__->bootstrap($VERSION);
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 B::Hooks::OP::PPAddr - Hook into opcode execution
 
+=head1 VERSION
+
+version 0.05
+
 =head1 SYNOPSIS
 
     #include "hook_op_check.h"
@@ -38,11 +46,11 @@ B::Hooks::OP::PPAddr - Hook into opcode execution
 
 =head1 DESCRIPTION
 
-This module provides a c api for XS modules to hook into the execution of perl
+This module provides a C API for XS modules to hook into the execution of perl
 opcodes.
 
 L<ExtUtils::Depends> is used to export all functions for other XS modules to
-use. Include the following in your Makefile.PL:
+use. Include the following in your F<Makefile.PL>:
 
     my $pkg = ExtUtils::Depends->new('Your::XSModule', 'B::Hooks::OP::PPAddr');
     WriteMakefile(
@@ -54,18 +62,24 @@ Your XS module can now include C<hook_op_ppaddr.h>.
 
 =head1 TYPES
 
-=head2 typedef OP *(*hook_op_ppaddr_cb_t) (pTHX_ OP *, void *user_data)
+=head2 OP
+
+    typedef OP *(*hook_op_ppaddr_cb_t) (pTHX_ OP *, void *user_data)
 
 Type that callbacks need to implement.
 
 =head1 FUNCTIONS
 
-=head2 void hook_op_ppaddr (OP *op, hook_op_ppaddr_cb_t cb, void *user_data)
+=head2 hook_op_ppaddr
+
+    void hook_op_ppaddr (OP *op, hook_op_ppaddr_cb_t cb, void *user_data)
 
 Replace the function to execute C<op> with the callback C<cb>. C<user_data>
 will be passed to the callback as the last argument.
 
-=head2 void hook_op_ppaddr_around (OP *op, hook_op_ppaddr_cb_t before, hook_op_ppaddr_cb_t after, void *user_data)
+=head2 hook_op_ppaddr_around
+
+    void hook_op_ppaddr_around (OP *op, hook_op_ppaddr_cb_t before, hook_op_ppaddr_cb_t after, void *user_data)
 
 Register the callbacks C<before> and C<after> to be called before and after the
 execution of C<op>. C<user_data> will be passed to the callback as the last
@@ -73,18 +87,44 @@ argument.
 
 =head1 SEE ALSO
 
+=over 4
+
+=item *
+
 L<B::Hooks::OP::Check>
 
+=back
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=B-Hooks-OP-PPAddr>
+(or L<bug-B-Hooks-OP-PPAddr@rt.cpan.org|mailto:bug-B-Hooks-OP-PPAddr@rt.cpan.org>).
+
 =head1 AUTHOR
 
-Florian Ragwitz E<lt>rafl@debian.orgE<gt>
+Florian Ragwitz <rafl@debian.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 CONTRIBUTORS
 
-Copyright (c) 2008 Florian Ragwitz
+=for stopwords Karen Etheridge Alexandr Ciornii
 
-This module is free software.
+=over 4
 
-You may distribute this code under the same terms as Perl itself.
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Alexandr Ciornii <alexchorny@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2008 by Florian Ragwitz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
